@@ -125,7 +125,7 @@ if(!type_cop) { # not copula models
              PACKAGE='GeoModels', VERBOSE = 0, NAOK = TRUE)$res
        }
    }
-
+    #print(-result)
          return(-result)
       }
       
@@ -148,12 +148,8 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
         other_nuis=as.numeric(nuisance[!sel]) 
         Mean=c(X1%*%mm1,X2%*%mm2)
         res=double(1)
-       # result <-  .C(as.character(fan),as.integer(corrmodel),as.double(data1), as.double(data2), 
-       #          as.integer(n),as.double(paramcorr), as.integer(weigthed), 
-       #            res=res,as.double(MM[colidx]),as.double(MM[rowidx]),  
-       #             as.double(other_nuis),
-       #             as.integer(local),as.integer(GPU),
-      #            PACKAGE='GeoModels',DUP = TRUE, NAOK=TRUE)$res
+       
+
         
         result=dotCall64::.C64(as.character(fan),
           SIGNATURE = c("integer","double","double", "integer","double","integer","double","double","double","double","integer","integer"),  
@@ -443,6 +439,7 @@ comploglik_biv2 <- function(param,colidx,rowidx, corrmodel, coords,data1,data2,f
  
    if(is.null(neighb)) {colidx=colidx+1; rowidx=rowidx+1}  #updating if #using "my distances from C" 
    data1=data[colidx]; data2=data[rowidx]                  ##using "RANN distances" 
+ 
 
    if((model==11||model==49||model==51)&&length(n)>1) {n1=n[colidx];n2=n[rowidx];n=c(n1,n2)} ## for binomials type models
    if(is.null(GPU)) GPU=0
@@ -492,12 +489,13 @@ if(!onlyvar){
         else                                   cl <- parallel::makeCluster(ncores,type = "FORK")
         parallel::setDefaultCluster(cl = cl)
         CompLikelihood <- optimParallel::optimParallel(par=param,fn=eval(as.name(lname)), 
-                              control=list(pgtol=1e-14, maxit=100000,factr = 1e8), # factr = 1e-10
+                              #control=list(pgtol=1e-14, maxit=100000,factr = 1e8), # factr = 1e-10
+                                control=list(factr=1e-10,pgtol=1e-14, maxit=100000), 
                               colidx=colidx,rowidx=rowidx,corrmodel=corrmodel,  coords=coords,
-                               data1=data1,data2=data2,fixed=fixed,fan=fname, lower=lower, method='L-BFGS-B',n=n,
+                               data1=data1,data2=data2,fixed=fixed,fan=fname, lower=lower,n=n,
                               namescorr=namescorr, namesnuis=namesnuis,namesparam=namesparam, namesaniso=namesaniso,
                          parallel = list(forward = FALSE,loginfo=FALSE),
-                              upper=upper,weigthed=weigthed,X=X, local=local,GPU=GPU, hessian=TRUE,MM=MM,aniso=aniso,type_cop=type_cop,cond_pair=cond_pair)
+                          upper=upper,weigthed=weigthed,X=X, local=local,GPU=GPU, hessian=TRUE,MM=MM,aniso=aniso,type_cop=type_cop,cond_pair=cond_pair)
          parallel::setDefaultCluster(cl=NULL)
          parallel::stopCluster(cl)
          }
